You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2004/10/13 12:28:16 UTC

svn commit: rev 54737 - in incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve: . schema/config

Author: akarasulu
Date: Wed Oct 13 03:28:14 2004
New Revision: 54737

Added:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractSchema.java
      - copied, changed from rev 54239, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractConfigSet.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/Schema.java
      - copied, changed from rev 54239, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java
Removed:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractConfigSet.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java
Modified:
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/ContextPartition.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/PartitionNexus.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/RootNexus.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxes.java
   incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java
Log:


Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/ContextPartition.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/ContextPartition.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/ContextPartition.java	Wed Oct 13 03:28:14 2004
@@ -25,7 +25,7 @@
  * context as a base suffix.  All JNDI Attributes entries at and under the
  * context of this suffix are stored within this partition.
  *
- * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
+ * @author <a href="mailto:direct   ory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
 public interface ContextPartition extends BackingStore

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/PartitionNexus.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/PartitionNexus.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/PartitionNexus.java	Wed Oct 13 03:28:14 2004
@@ -115,13 +115,6 @@
     Attributes lookup( Name dn, String [] attrIds ) throws NamingException;
 
     /**
-     * Gets the RootDSE associated with this BackendNexus.
-     *
-     * @return the Attributes contained within the Root DSA Entry.
-     */
-    Attributes getRootDSE();
-
-    /**
      * Registers an ContextPartition with this BackendManager.  Called by each
      * ContextPartition implementation after it has started to register for
      * backend operation calls.  This method effectively puts the 

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/RootNexus.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/RootNexus.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/RootNexus.java	Wed Oct 13 03:28:14 2004
@@ -115,7 +115,9 @@
 
 
     /**
-     * @see PartitionNexus#getRootDSE()
+     * Get's the RootDSE entry for the DSA.
+     *
+     * @return the attributes of the RootDSE
      */
     public Attributes getRootDSE() 
     {

Copied: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractSchema.java (from rev 54239, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractConfigSet.java)
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractConfigSet.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/AbstractSchema.java	Wed Oct 13 03:28:14 2004
@@ -17,6 +17,10 @@
 package org.apache.eve.schema.config;
 
 import org.apache.ldap.common.util.ArrayUtils;
+import org.apache.ldap.common.schema.*;
+
+import java.util.Map;
+import java.util.Collections;
 
 /**
  * Document me.
@@ -24,7 +28,7 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public class AbstractConfigSet implements ConfigSet
+public class AbstractSchema implements Schema
 {
     private static final String DEFAULT_OWNER = "uid=admin,ou=system";
     private static final String DEFAULT_SCHEMA_NAME = "default";
@@ -39,7 +43,7 @@
     // ------------------------------------------------------------------------
 
 
-    public AbstractConfigSet( String owner, String schemaName, String[] dependencies )
+    public AbstractSchema( String owner, String schemaName, String[] dependencies )
     {
         if ( owner == null )
         {
@@ -86,4 +90,53 @@
     {
         return new String[0];
     }
+
+
+    public Map getComparators()
+    {
+        return Collections.EMPTY_MAP;
+    }
+
+
+    public Map getNormalizers()
+    {
+        return Collections.EMPTY_MAP;
+    }
+
+
+    public SyntaxChecker[] getSyntaxCheckers()
+    {
+        return new SyntaxChecker[0];
+    }
+
+
+    public Syntax[] getSyntaxes()
+    {
+        return new Syntax[0];
+    }
+
+
+    public MatchingRule[] getMatchingRules()
+    {
+        return new MatchingRule[0];
+    }
+
+
+    public AttributeType[] getAttributeTypes()
+    {
+        return new AttributeType[0];
+    }
+
+
+    public ObjectClass[] getObjectClasses()
+    {
+        return new ObjectClass[0];
+    }
+
+
+    // ------------------------------------------------------------------------
+    // Utility Methods
+    // ------------------------------------------------------------------------
+
+
 }

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxes.java
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxes.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/CoreSyntaxes.java	Wed Oct 13 03:28:14 2004
@@ -17,10 +17,11 @@
 package org.apache.eve.schema.config;
 
 
-import org.apache.ldap.common.schema.Syntax;
-import org.apache.ldap.common.schema.BaseSyntax;
+import org.apache.ldap.common.schema.*;
 import org.apache.eve.schema.SyntaxCheckerRegistry;
 
+import java.util.Map;
+
 
 /**
  * A Syntax schema object configuration set for the core LDAP schema in Section
@@ -457,6 +458,40 @@
         return syntaxes;
     }
 
+    public Map getComparators()
+    {
+        return null;
+    }
+
+    public Map getNormalizers()
+    {
+        return null;
+    }
+
+    public SyntaxChecker[] getSyntaxCheckers()
+    {
+        return new SyntaxChecker[0];
+    }
+
+    public Syntax[] getSyntaxes()
+    {
+        return new Syntax[0];
+    }
+
+    public MatchingRule[] getMatchingRules()
+    {
+        return new MatchingRule[0];
+    }
+
+    public AttributeType[] getAttributeTypes()
+    {                                                               
+        return new AttributeType[0];
+    }
+
+    public ObjectClass[] getObjectClasses()
+    {
+        return new ObjectClass[0];
+    }
 
     /**
      * Used to access protected mutators of BaseSyntax from within this class.

Copied: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/Schema.java (from rev 54239, incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java)
==============================================================================
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java	Wed Oct 13 03:28:14 2004
@@ -27,7 +27,7 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface SyntaxConfigSet extends ConfigSet
+public interface SyntaxConfigSet extends Schema
 {
     Syntax[] load( SyntaxCheckerRegistry registry );
 }
--- incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/ConfigSet.java	(original)
+++ incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/Schema.java	Wed Oct 13 03:28:14 2004
@@ -16,6 +16,10 @@
  */
 package org.apache.eve.schema.config;
 
+import org.apache.ldap.common.schema.*;
+
+import java.util.Map;
+
 
 /**
  * A configuration of like Schema objects bundled together and identified as a
@@ -24,18 +28,18 @@
  * @author <a href="mailto:directory-dev@incubator.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface ConfigSet
+public interface Schema
 {
     /**
      * Gets the name of the owner of the schema objects within this
-     * ConfigSet.
+     * Schema.
      *
      * @return the identifier for the owner of this set's objects
      */
     String getOwner();
 
     /**
-     * Gets the name of the logical schema the objects of this ConfigSet
+     * Gets the name of the logical schema the objects of this Schema
      * belong to: e.g. krb5-kdc may be the logical LDAP schema name.
      *
      * @return the name of the logical schema
@@ -44,10 +48,24 @@
 
     /**
      * Gets the names of other schemas that this objects within this
      * ConfigSet depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *
      * @return the String names of schema dependencies
      */
     String[] getDependencies();
+
+    Map getComparators();
+
+    Map getNormalizers();
+
+    SyntaxChecker[] getSyntaxCheckers();
+
+    Syntax[] getSyntaxes();
+
+    MatchingRule[] getMatchingRules();
+
+    AttributeType[] getAttributeTypes();
+
+    ObjectClass[] getObjectClasses();
 }
@@ -44,10 +48,24 @@
     /**
      * Gets the names of other schemas that this objects within this
-     * ConfigSet depends upon.  These dependent schemas are those
+     * Schema depends upon.  These dependent schemas are those
      * whose ConfigurationSets will be processed first.
      *

Modified: incubator/directory/eve/trunk/backend/core/src/java/org/apache/eve/schema/config/SyntaxConfigSet.java
==============================================================================